@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 """An application for keeping track of your time."""
 
 # Default to new-style classes.
@@ -1341,8 +1340,8 @@ def main():
             print('Loading settings from %s' % settings_file)
         settings.load(settings_file)
     if opts.debug:
-        print('Loading time log from %s' % settings.get_timelog_file())
         print('Assuming date changes at %s' % settings.virtual_midnight)
+        print('Loading time log from %s' % settings.get_timelog_file())
     timelog = TimeLog(settings.get_timelog_file(),
                       settings.virtual_midnight)
     if settings.task_list_url:
@@ -1365,8 +1364,8 @@ def main():
         else:
             icons = [SimpleStatusIcon, OldTrayIcon, AppIndicator]
         if opts.debug:
-            print('Tray icon preference: %s' % ', '.join(icon_class.__name__)
-                                                         for icon_class in icons)
+            print('Tray icon preference: %s' % ', '.join(icon_class.__name__
+                                                         for icon_class in icons))
         for icon_class in icons:
             tray_icon = icon_class(main_window)
             if tray_icon.available():
